from .contract import (
    JettonMasterStandard,
    JettonWalletStandard,

    JettonMasterStablecoin,
    JettonWalletStablecoin,
)

__all__ = [
    "JettonMasterStandard",
    "JettonWalletStandard",

    "JettonMasterStablecoin",
    "JettonWalletStablecoin",
]
